const { Permissions } = require("detritus-client/lib/constants")
const { decimalToHexColor } = require("#utils/color");

module.exports.DISCORD_INVITES = Object.freeze({
  support: "https://discord.gg/8c4p6xcjru",
  privacy: "https://discord.gg/sQs8FhcTGh",
  invite: "https://discord.gg/cHd28DrM7f",
  help: "https://discord.gg/xQNBB3WFne",
  feedback_cardstack: "https://discord.gg/qwrBNeK7dt",
})

module.exports.DEFAULT_BOT_NAME = 'labsCore'

// The first prefix in this list is considered the
// default prefix and will be displayed in various
// places throughout the app
module.exports.DEFAULT_PREFIXES = ['lc.', 'ic.', 'pb.']

module.exports.PRIVACY_POLICY_SECTIONS = [
  '### Summary\n- We do not store or collect information about our users or their servers.\n- We share certain data with third parties that is strictly necessary to operate certain functionality.',
  '### The information we collect\nWe use technology to log unexpected issues that may occur when interacting with our application. These logs are only shared with the developers of the application and not accessible to the public. Logged information includes:\n- Your username, server and channel\n- The command you executed, as well as its arguments (excluding images)',
  'Images modified via our proprietary api are directly uploaded to Discord and never permanently stored anywhere other than the requested channel by us.\n- The only exception to this is the art command, wallpapers generated via art will be publicly shared in the support server for anyone to view.)',
  '### Third Parties\nWe use a variety of third party products and services to operate certain functionality of our application. Information shared with third parties is strictly limited to information necessary to provide the functionality (command arguments).\nWe do not offer any functionality that shares details about users, a channel or a server with third parties and their services.'
]

module.exports.PRIVACY_POLICY_LAST_UPDATE = 1699120509970
module.exports.PRIVACY_POLICY_PREVIOUS_REVISION = "privacy_june22.1dborzeh8yhs"

module.exports.SUPPORT_ARTICLES = {
  AGE_RESTRICTED_CHANNELS: 115000084051
}

module.exports.OPEN_SOURCE_REPOSITORY_URL = "https://gitlab.com/bignutty/labscore"

module.exports.COLORS = Object.freeze({
  error: 16404060,
  success: 8191849,
  warning: 15708731,
  embed: 2368553,
  brand: 65381,
  nsfw: 15159978,
  incognito: 10057726,
})

module.exports.COLORS_HEX = Object.freeze({
  error: decimalToHexColor(module.exports.COLORS.error),
  success: decimalToHexColor(module.exports.COLORS.success),
  warning: decimalToHexColor(module.exports.COLORS.warning),
  embed: decimalToHexColor(module.exports.COLORS.embed),
  brand: decimalToHexColor(module.exports.COLORS.brand),
  nsfw: decimalToHexColor(module.exports.COLORS.nsfw),
  incognito: decimalToHexColor(module.exports.COLORS.incognito),
})

// Permission requirements that apply to commands
module.exports.PERMISSION_GROUPS = Object.freeze({
  // Baseline permission set for regular commands
  baseline: [Permissions.SEND_MESSAGES, Permissions.VIEW_CHANNEL, Permissions.USE_EXTERNAL_EMOJIS, Permissions.EMBED_LINKS, Permissions.READ_MESSAGE_HISTORY],
  // Baseline permission set for slash commands
  baseline_slash: [
    Permissions.SEND_MESSAGES, Permissions.EMBED_LINKS,
    // Related to using user commands
    Permissions.USE_APPLICATION_COMMANDS,
    1n << 50n // Use external apps
  ],

  // Permissions for all commands that use attachments
  attachments: [Permissions.ATTACH_FILES],
})

module.exports.BADGE_ICONS = Object.freeze({
  "active_developer": "<:b:1263607989873414196>",
  "bot_developer": "<:b:1263605652337463489>",
  "bug_hunter": "<:b:1263605576773013616>",
  "bug_hunter_lvl2": "<:b:1263607090501517372>",
  "early_supporter": "<:b:1263607076173905950>",
  "hypesquad_events": "<:ico_badge_hypesquad:1263607109262770338>",
  "hypesquad_balance": "<:b:1263607122659119255>",
  "hypesquad_bravery": "<:b:1263607134596104273>",
  "hypesquad_brilliance": "<:b:1263607149721026600>",
  "mod_program": "<:b:1263605447001243698> ",
  "nitro": "<:b:1263607232558399631>",
  "partner": "<:b:1263605756356464751>",
  "staff": "<:b:1263605715688231035>"
})

// labscore_nxt/nextgen icons
module.exports.ICONS_NEXTGEN = Object.freeze({
  "button_mag": "<:ico_button_mag:1271212564122173552>",
  "button_thermometer": "<:ico_button_thermometer:1263593823016062987>",
  "button_trash": "<:ico_button_trash:1271212355883372716>",
  "button_user_profile_swap": "<:ico_button_user_profile_swap:1263594003442700368>",
  "button_translate": "<:ico_button_translate:1304161023288283249>",

  "button_chevron_left": "<:button_chevron_left:1263594121256374413>",
  "button_chevron_right": "<:button_chevron_right:1263594132023279669>",

  "open_in_new": "<:nxt_ico_open_in_new:1363577624252649675>",

  "button_full_coverage": "<:ico_full_coverage:1341535912017793045>",
  "button_wolfram_compute": "<:ico_wolfram_compute:1342276477269577758>",

  "gs_auto_awesome": "<:ico_gs_auto_awesome:1352186988416995380>",

  /* Brands */
  "brand": "<:nxt_ico_brand:1363557610573533365>",
  "brand_gray": "<:nxt_ico_brand_gray:1363557640617329001>",
  "brand_discord": "<:nxt_ico_discord:1363557748951748668>",
  "brand_gitlab": "<:nxt_ico_brand_gitlab:1363557620404850791>",
  "brand_google": "<:nxt_ico_brand_google:1363557630156476446>",

  /* Icon Toolkit */
  "analytics": "<:nxt_ico_analytics:1363556442103218358>",
  "calendar": "<:nxt_ico_calendar:1363557651224461402>",
  "clock": "<:nxt_ico_clock:1363557682853974188>",
  "connection": "<:nxt_ico_connection:1363557703594672148>",
  "connection_warning": "<:nxt_ico_connection_warning:1363557714747457556>",
  "flag": "<:nxt_ico_flag:1363558782726049792>",
  "hashmark": "<:nxt_ico_hashmark:1363557659977977978>",
  "hashmark_warning": "<:nxt_ico_hashmask_warning:1363557670782632106>",
  "home": "<:nxt_ico_home:1363558803324276968>",
  "image": "<:nxt_ico_image:1363558822907613215>",
  "image_stack": "<:nxt_ico_image_stack:1363558834043617370>",
  "list_stack": "<:nxt_ico_list_stack:1363558867698712748>",
  "newspaper": "<:nxt_ico_newspaper:1363559949950517518>",
  "note": "<:nxt_ico_note:1363559965603926116>",
  "padlock": "<:nxt_ico_lock:1363558889592721658>",
  "pencil": "<:nxt_ico_pencil:1363559974189662279>",
  "pencil_note": "<:nxt_ico_pencil_note:1363559984801124502>",
  "planet": "<:nxt_ico_planet:1363559994729168906>",
  "privacy_policy": "<:nxt_ico_privacy_policy:1363560893459464392>",
  "qr": "<:nxt_ico_qr:1363560903894634557>",
  "robot": "<:nxt_ico_robot:1363560971263541520>",
  "rocket": "<:nxt_ico_rocket:1363573889359151275>",
  "search": "<:nxt_ico_search:1363573898125381882>",
  "search_square": "<:nxt_ico_search_square:1363573906505465986>",
  "settings": "<:nxt_ico_settings:1363573916081197096>",
  "shield": "<:nxt_ico_shield:1363573923177955470>",
  "sparkles": "<:nxt_ico_sparkles:1363573949535096963>",
  "tools": "<:nxt_ico_tools:1363574671227883591>",

  /* Discord */
  "discord_boost": "<:nxt_ico_boost:1363556530670272602>",
  "discord_nitro": "<:nxt_ico_nitro:1363559957483749487>",
  "discord_status_offline": "<:nxt_ico_disc_status_offline:1363557729855082697>",
  "discord_status_online": "<:nxt_ico_disc_status_online:1363557739527409794>",

  "attachment": "<:nxt_ico_attachment_image:1363556507811184780>",
  "attachment_file": "<:nxt_ico_attachment_file:1363556499162534049>",
  "emoji": "<:nxt_ico_emoji:1363557759701876937>",
  "forward": "<:nxt_ico_forward:1363558792746369045>",
  "id": "<:nxt_ico_id:1363558813055189073>",
  "link": "<:nxt_ico_link:1363558856776486982>",
  "locale": "<:nxt_ico_locale:1363558878872080414>",
  "message": "<:nxt_ico_message:1363559929524261074>",
  "reply": "<:nxt_ico_reply:1363560954725535845>",
  "slash": "<:nxt_ico_slash:1363573933567377448>",
  "sticker": "<:nxt_ico_sticker:1363574636343853167>",

  "at": "<:nxt_ico_at:1363556490169946254>",
  "audio": "<:nxt_ico_audio:1363556520809201724>",
  "microphone": "<:nxt_ico_microphone:1363559939297116410>",
  "stage": "<:nxt_ico_stage:1363573950684332263>",

  /* Users */
  "user": "<:nxt_ico_user:1363574680337780796>",
  "user_circle": "<:nxt_ico_user_circle:1363574689087098990>",
  "user_king": "<:nxt_ico_user_king:1363574707441373215>",
  "user_group": "<:nxt_ico_user_group:1363574698570416358>",
  "user_shield": "<:nxt_ico_user_shield:1363575244568137870>",
  "user_stack": "<:nxt_ico_user_stack:1363575255016149224>",

  "arrow_down": "<:nxt_ico_arrow_down:1363556451574092037>",
  "arrow_left": "<:nxt_ico_arrow_left:1363556461355073566>",
  "arrow_right": "<:nxt_ico_arrow_right:1363556471303831552>",
  "arrow_up": "<:nxt_ico_arrow_up:1363556479486922862>",

  "downvote": "<:nxt_ico_rate_downvote:1363560934676893918>",
  "upvote": "<:nxt_ico_rate_upvote:1363560945103667380>",

  "album": "<:nxt_ico_album:1363556433848827954>",
  "comments": "<:nxt_ico_comments:1363557692643344547>",
  "playlist": "<:nxt_ico_playlist:1363560877537759342>",
  "thumb_up": "<:nxt_ico_thumb_up:1363574661572591797>",
  "thumb_down": "<:nxt_ico_thumb_down:1363574653213212682>",
  "eye": "<:nxt_ico_eye:1363558773469479093>",

  "exclaim": "<:nxt_ico_exclaim:1363557770158411888>",
  "exclaim_green": "<:nxt_ico_exclaim_green:1363558735955493207>",
  "exclaim_pink": "<:nxt_ico_exclaim_pink:1363558745811980458>",
  "exclaim_red": "<:nxt_ico_exclaim_red:1363558755245096991>",
  "exclaim_yellow": "<:nxt_ico_exclaim_yellow:1363558764661182465>",

  "information": "<:nxt_ico_information:1363558844696887406>",
  "question": "<:nxt_ico_question:1363560925407219792>",
  "warning": "<:nxt_ico_warning:1363575266030391557>",

  /* Weds */
  "weds_air_quality_0": "<:nxt_ico_weds_quality_0:1363575285395492955>",
  "weds_air_quality_1": "<:nxt_ico_weds_quality_1:1363575293671112735>",
  "weds_air_quality_2": "<:nxt_ico_weds_quality_2:1363575303754088800>",
  "weds_air_quality_3": "<:nxt_ico_weds_quality_3:1363575320925700248>",
  "weds_air_quality_4": "<:nxt_ico_weds_quality_4:1363576106673770546>",

  "weds_uv_index_0": "<:nxt_ico_weds_uv_0:1363576126177284106>",
  "weds_uv_index_1": "<:nxt_ico_weds_uv_1:1363576146469453975>",
  "weds_uv_index_2": "<:nxt_ico_weds_uv_2:1363576155499659395>",
  "weds_uv_index_3": "<:nxt_ico_weds_uv_3:1363576164651630743>",
  "weds_uv_index_4": "<:nxt_ico_weds_uv_4:1363576174638403634>",

  "weds_moon": "<:nxt_ico_weds_moon:1363575276931645742> ",
  "weds_sun": "<:nxt_ico_weds_sun:1363576116492632307> ",

  "weds_warning": "<:nextgen_ico_weds_warning:1329933496780722357>",
  // These icon names (weds_warning_:warningId) have to be synced with the server (/utils_service/endpoints/weather.js).
  "weds_warning_wind": "<:nextgen_ico_weds_warning_wind:1329933507006435359>",
  "weds_warning_tropicalstorm": "<:nextgen_ico_weds_warning_tropica:1329933486819115079>",
  "weds_warning_tornado": "<:nextgen_ico_weds_warning_tornado:1329933476522365101>",
  "weds_warning_temperature": "<:nextgen_ico_weds_warning_heat:1329933467370258452>",
  "weds_warning_frost": "<:nextgen_ico_weds_warning_frost:1329933455898837051>",
  "weds_warning_flood": "<:nextgen_ico_weds_warning_flood:1329933447401046079>",
})

// nextgen icons legacy name -> new name mappings
module.exports.ICONS_NEXTGEN_LEGACY_MAPPINGS = Object.freeze({
  "link_open_external": "open_in_new",
  "stars": "sparkles",

  "example": "pencil_note",
  "list": "list_stack",
  "definition": "book_search",
  "latency": "connection",
  "mag": "search",
  "search": "search_square",
  "trend": "analytics",

  "activity": "rocket",
  "agreements": "privacy_policy",
  "apps": "shapes",
  "channel": "hashmark",
  "channel_nsfw": "hashmark_warning",
  "mention": "at",

  "user_multiple": "user_group",
  "user_profile": "user_circle",

  "discord": "brand_discord",
  "gitlab": "brand_gitlab",
  "generative_ai": "ai_writing",

  "boost": "discord_boost",
  "nitro": "discord_nitro",

  "moon": "weds_moon",
  "sun": "weds_sun",

  "user_card": "user_stack",

  "visible": "eye",

  "status_offline": "discord_status_offline",
  "status_online": "discord_status_online",

  "exclaim_0": "exclaim",
  "exclaim_1": "exclaim_green",
  "exclaim_2": "exclaim_yellow",
  "exclaim_3": "exclaim_red",
  "exclaim_4": "exclaim_pink",

  "uv_index_0": "weds_uv_index_0",
  "uv_index_1": "weds_uv_index_1",
  "uv_index_2": "weds_uv_index_2",
  "uv_index_3": "weds_uv_index_3",
  "uv_index_4": "weds_uv_index_4",

  "air_quality_0": "weds_air_quality_0",
  "air_quality_1": "weds_air_quality_1",
  "air_quality_2": "weds_air_quality_2",
  "air_quality_3": "weds_air_quality_3",
  "air_quality_4": "weds_air_quality_4",

  "stat_comments": "comments",
  "stat_likes": "thumb_up",
  "stat_people": "user_group",
  "stat_videos": "playlist",
  "stat_views": "eye",

  // WEATHER BLOCK
  "weather_warning_generic": "weds_warning",
  "weather_warning_storm": "weds_warning_wind",
  "weather_warning_tropical_storm": "weds_warning_tropicalstorm",
  "weather_warning_tornado": "weds_warning_tornado",
  "weather_warning_heat": "weds_warning_temperature",
  "weather_warning_frost": "weds_warning_frost",
  "weather_warning_flood": "weds_warning_flood",
})

// TODO: Load icon configuration from server
module.exports.ICONS = Object.freeze({
  "brand": "<:ico_brand_2024:1263593574478643221>",
  "flask_incognito": "<:ico_flask_incognito:1263608937459224688>",

  "flask_mini": "<:ico_subt_flask:1263593669215256597>",
  "subtext_lightbulb": "<:ico_subt_lightbulb:1263593690358616084>",
  "subtext_translate": "<:ico_subtext_translate:1323844562875187291>",

  "button_mag": "<:ico_button_mag:1271212564122173552>",
  "button_thermometer": "<:ico_button_thermometer:1263593823016062987>",
  "button_trash": "<:ico_button_trash:1271212355883372716>",
  "button_user_profile_swap": "<:ico_button_user_profile_swap:1263594003442700368>",
  "button_translate": "<:ico_button_translate:1304161023288283249>",

  "button_chevron_left": "<:button_chevron_left:1263594121256374413>",
  "button_chevron_right": "<:button_chevron_right:1263594132023279669>",

  "link_open_external": "<:ico_link_open_external:1266361666702934071>",

  "home": "<:ico_home:1263593114694586400>",
  "image": "<:ico_image:1263593101755289610>",
  "search": "<:ico_search:1263593084810301493>",
  "shield": "<:ico_shield:1263593069530583171>",
  "stars": " <:ico_stars:1263593055512957122>",
  "tools": "<:ico_tools:1263593031903346698>",

  "agreements": "<:ico_agreements:1263592506017189988>",
  "calendar": "<:ico_calendar:1263592493505577041>",
  "certificate": "<:ico_certificate:1263592480461553794>",
  "clock": "<:ico_clock:1263592462841020537>",
  "definition": "<:ico_definition:1263592450136473684>",
  "example": "<:ico_example:1263592408021471253>",
  "equals": "<:ico_equals:1266486823992168468>",
  "flag": "<:ico_flag:1263592391630127114>",
  "list": "<:ico_list:1263592365994803306>",
  "mag": "<:ico_mag:1263592345845108747>",
  "note": "<:ico_note:1263592327856001105>",
  "padlock": "<:ico_padlock:1263592313280528434>",
  "pencil": "<:ico_pencil:1263592296570421351>",
  "planet": "<:ico_planet:1263592281685098568>",
  "qr": "<:ico_qr:1263592268053348393>",
  "robot": "<:ico_robot:1263592241776164893>",
  "settings": "<:ico_settings:1263592222784356402>",
  "trend": "<:ico_trend:1263592191981256786>",
  "visible": "<:ico_visible:1263592172436066374>",

  "activity": "<:ico_activity:1263591756570689682>",
  "apps": "<:ico_apps:1271251455818469530>",
  "attachment": "<:ico_attachment:1263591742452666378>",
  "boost": "<:ico_boost:1263591721741193226>",
  "discord": "<:ico_discord:1263591704439689226>",
  "emoji": "<:ico_emoji:1263591687691833479>",
  "id": "<:ico_id:1329911839693471834>",
  "link": "<:ico_link:1263591669727629406>",
  "locale": "<:ico_locale:1263591655143903314>",
  "message": "<:ico_message:1263591634537545788>",
  "nitro": "<:ico_nitro:1263591618603126865>",
  "reply": "<:ico_reply:1263591597778407474>",
  "slash": "<:ico_slash:1263591582884434091>",
  "sticker": "<:ico_sticker:1263591567676145754>",

  "audio": "<:ico_audio:1263591286779412480>",
  "channel": "<:ico_channel:1263591268211097662>",
  "channel_nsfw": "<:ico_channel_nsfw:1263591241057173514>",
  "mention": "<:ico_mention:1263591215429849189>",
  "microphone": "<:ico_microphone:1263591199911051427>",
  "stage": "<:ico_stage:1271252974529810482>",

  "user": "<:ico_user:1263590776617828462>",
  "user_card": "<:ico_user_card:1263590467166277698>",
  "user_king": "<:ico_user_king:1263590410228334637>",
  "user_multiple": "<:ico_user_multiple:1263590373754929162>",
  "user_profile": "<:ico_user_profile:1263590325927284827>",
  "user_shield": "<:ico_user_shield:1263590283552231444>",

  "status_offline": "<:ico_status_offline:1263590209644134520>",
  "status_online": "<:ico_status_online:1263590195333169204>",

  "arrow_down": "<:ico_arrow_down:1263589989778853928>",
  "arrow_left": "<:ico_arrow_left:1263590017159139339>",
  "arrow_right": "<:ico_arrow_right:1263590004886863902>",
  "arrow_up": "<:ico_arrow_up:1263590030174195833>",

  "stat_comments": "<:ico_stat_comments:1263589816407162911>",
  "stat_likes": "<:ico_stat_likes:1263589802289397903>",
  "stat_people": "<:ico_stat_people:1263589790251618434>",
  "stat_videos": "<:ico_stat_videos:1263589779258216508>",
  "stat_views": "<:ico_stat_views:1263589767900299385>",

  "downvote": "<:ico_downvote:1263589702171103242>",
  "upvote": "<:ico_upvote:1263589685243154515>",

  "gitlab": "<:ico_gitlab:1263589629999976561>",

  "generative_ai": "<:ico_generative_ai:1263589586387468349>",
  "latency": "<:ico_latency:1263589536139710566>",

  "moon": "<:ico_moon:1263589209059496137> ",
  "sun": "<:ico_sun:1263589195251716116> ",

  "exclaim_0": "<:ico_exclaim_0:1263588923670532106>",
  "exclaim_1": "<:ico_exclaim_1:1263588911754510538>",
  "exclaim_2": "<:ico_exclaim_2:1263588899670855712>",
  "exclaim_3": "<:ico_exclaim_3:1263588890485457046>",
  "exclaim_4": "<:ico_exclaim_4:1263588879307640883>",
  "question_large": "<:ico_question_large:1263589058999750787>",

  // Used by weds
  "air_quality_0": "<:ic_quality_0:1278416585739997184>",
  "air_quality_1": "<:ic_quality_1:1278416596506906664>",
  "air_quality_2": "<:ic_quality_2:1278416607055708251>",
  "air_quality_3": "<:ic_quality_3:1278416621215420506>",
  "air_quality_4": "<:ic_quality_4:1278416629973254175>",

  "uv_index_0": "<:ic_uv_0:1278416641633550336>",
  "uv_index_1": "<:ic_uv_1:1278416651569856522>",
  "uv_index_2": "<:ic_uv_2:1278416662974038118>",
  "uv_index_3": "<:ic_uv_3:1278416673761919006>",
  "uv_index_4": "<:ic_uv_4:1278416684763451485>",

  // These icon names (weather_:conditionId) have to be synced with the server.
  "weather_blizzard": "<:ico_w_blizzard:1263583584850022460>",
  "weather_blowing_snow": "<:ico_w_blowing_snow:1263583671726903377>",
  "weather_clear_day": "<:ico_w_clear_day:1263583684158820383>",
  "weather_clear_night": "<:ico_w_clear_night:1263583704069181622>",
  "weather_cloudy": "<:ico_w_cloudy:1263583715704180879>",
  "weather_drizzle": "<:ico_w_drizzle:1263583728769302609>",
  "weather_flurries": "<:ico_w_flurries:1263583744053215333>",
  "weather_haze_fog_dust_smoke": "<:ico_w_haze_fog_dust_smoke:1263583772885127188>",
  "weather_heavy_rain": "<:ico_w_heavy_rain:1263583786428399717>",
  "weather_heavy_snow": "<:ico_w_heavy_snow:1263583800957337640>",
  "weather_icy": "<:ico_w_icy:1263583815717359658>",
  "weather_isolated_scattered_thunderstorms_day": "<:ico_w_iso_scattered_tstorm_day:1263583831433150526>",
  "weather_isolated_scattered_thunderstorms_night": "<:ico_w_iso_scattered_tstorm_night:1263584235847942246>",
  "weather_isolated_thunderstorms": "<:ico_w_isolated_thunderstorms:1263584283264548986>",
  "weather_mixed_rain_hail_sleet": "<:ico_w_mixed_rain_sleet_hail:1263584310598959185>",
  "weather_mixed_rain_snow": "<:ico_w_mixed_rain_snow:1263584323752296468>",
  "weather_mostly_clear_day": "<:ico_w_mostly_clear_day:1263584337471864986>",
  "weather_mostly_clear_night": "<:ico_w_mostly_clear_night:1263584621493489784>",
  "weather_mostly_cloudy_day": "<:ico_w_mostly_cloudy_day:1263584634793623575>",
  "weather_mostly_cloudy_night": "<:ico_w_mostly_cloudy_night:1263584648508866662>",
  "weather_partly_cloudy_day": "<:ico_w_partly_cloudy_day:1263584669644095558>",
  "weather_partly_cloudy_night": "<:ico_w_partly_cloudy_night:1263584672844087316>",
  "weather_scattered_showers_day": "<:ico_w_scattered_showers_day:1263584683657134101>",
  "weather_scattered_showers_night": "<:ico_w_scattered_showers_night:1263584693555560478>",
  "weather_scattered_snow_showers_day": "<:ico_w_scattered_snow_showers_day:1263584731178467449> ",
  "weather_scattered_snow_showers_night": "<:ico_scattered_snow_showers_night:1263584941996904448>",
  "weather_showers_rain": "<:ico_w_showers_rain:1263584960359567381>",
  "weather_showers_snow": "<:ico_w_snow_showers_snow:1263584991552471171>",
  "weather_sleet_hail": "<:ico_w_sleet_hail:1263584973697581140>",
  "weather_strong_thunderstorms": "<:ico_w_strong_tstorms:1263585008589869056>",
  "weather_tornado": "<:ico_w_tornado:1263585022552707154>",
  "weather_tropical_storm_hurricane": "<:ico_w_tropical_storm_hurricane:1263585036058366003>",
  "weather_very_cold": "<:very_cold:1278416835661926495>",
  "weather_very_hot": "<:very_hot:1278416845560348732>",
  "weather_windy": "<:ico_w_windy_breezy:1263585171849084968>",

  "weather_warning_generic": "<:ico_weather_warning:1269684384966119444>",
  // These icon names (weather_warning_:warningId) have to be synced with the server.
  "weather_warning_storm": "<:ico_weather_wind:1269680554140242066>",
  "weather_warning_tropical_storm": "<:ico_weather_tropicalstorm:1269680544430428312>",
  "weather_warning_tornado": "<:ico_weather_tornado:1269680535517794334>",
  "weather_warning_heat": "<:ico_weather_heat:1269680524897681564>",
  "weather_warning_frost": "<:ico_weather_frost:1269680515145797652>",
  "weather_warning_flood": "<:ico_weather_flood:1269680505519865982>",

  /* Maps Experience */

  "maps_location_pin": "<:maps_red_pin:1307493148800581643>",

  "maps_star": "<:ico_star:1306748432496463903>",
  "maps_star_half": "<:ico_star_half:1306748464037761064>",
  "maps_star_empty": "<:ico_star_empty_alt:1306748453187096598>",

  // These icon names (maps_:type_pin) have to be synced
  // with the server (search_service/utils/places).
  "maps_airport_pin": "<:maps_airport_pin:1307489862349492294>",
  "maps_atm_pin": "<:maps_atm_pin:1307491755188555898>",
  "maps_bank_dollar_pin": "<:maps_bank_dollar_pin:1307491765493698630>",
  "maps_bank_euro_pin": "<:maps_bank_euro_pin:1307491810687320175>",
  "maps_bank_intl_pin": "<:maps_bank_intl_pin:1307491820749455380>",
  "maps_bank_jp_pin": "<:maps_bank_jp_pin:1307491870703747142>",
  "maps_bank_pound_pin": "<:maps_bank_pound_pin:1307491883941101729>",
  "maps_bank_rmb_pin": "<:maps_bank_rmb_pin:1307491895836016700>",
  "maps_bank_won_pin": "<:maps_bank_won_pin:1307491909559779438>",
  "maps_bar_pin": "<:maps_bar_pin:1307491920880205936>",
  "maps_bike_pin": "<:maps_bike_pin:1307491931168837643>",
  "maps_boating_pin": "<:maps_boating_pin:1307491944410382416>",
  "maps_bridge_pin": "<:maps_bridge_pin:1307491957861388288>",
  "maps_cafe_pin": "<:maps_cafe_pin:1307491969110511646>",
  "maps_camera_pin": "<:maps_camera_pin:1307491997090582608>",
  "maps_camping_pin": "<:maps_camping_pin:1307492059736969268>",
  "maps_car_rental_pin": "<:maps_car_rental_pin:1307492307406426194>",
  "maps_cemetery_jp_pin": "<:maps_cemetery_jp_pin:1307492318873391245>",
  "maps_cemetery_pin": "<:maps_cemetery_pin:1307492328801566741>",
  "maps_city_office_jp_pin": "<:maps_city_office_jp_pin:1307492339471745054>",
  "maps_civic_bldg_pin": "<:maps_civic_bldg_pin:1307492350766874705>",
  "maps_civic_bldg_red_pin": "<:maps_civic_bldg_red_pin:1307492360883798046>",
  "maps_civil_office_jp_pin": "<:maps_civil_office_jp_pin:1307492371566690457>",
  "maps_convenience_pin": "<:maps_convenience_pin:1307492382593384509>",
  "maps_dice_pin": "<:maps_dice_pin:1307492393494380594>",
  "maps_dolphin_pin": "<:maps_dolphin_pin:1307492405636894822>",
  "maps_dot_gray_pin": "<:maps_dot_gray_pin:1307492434980114492>",
  "maps_dot_green_pin": "<:maps_dot_green_pin:1307492525841453157>",
  "maps_dot_light_gray_pin": "<:maps_dot_light_gray_pin:1307492536067031060>",
  "maps_dot_red_pin": "<:maps_dot_red_pin:1307492545793622036>",
  "maps_ev_pin": "<:maps_ev_pin:1307492558217285652>",
  "maps_event_venue_pin": "<:maps_event_venue_pin:1307492569927647293>",
  "maps_ferriswheel_pin": "<:maps_ferriswheel_pin:1307492583135645770>",
  "maps_fire_jp_pin": "<:maps_fire_jp_pin:1307492593587978251>",
  "maps_fishing_pin": "<:maps_fishing_pin:1307492603637403708>",
  "maps_flower_pin": "<:maps_flower_pin:1307492617017229342>",
  "maps_gas_pin": "<:maps_gas_pin:1307492627561709649>",
  "maps_glass_pin": "<:maps_glass_pin:1307492648109477960>",
  "maps_golf_pin": "<:maps_golf_pin:1307492660591722570>",
  "maps_government_cn_pin": "<:maps_government_cn_pin:1307492671157440522>",
  "maps_hiking_pin": "<:maps_hiking_pin:1307492767307530262>",
  "maps_historic_cn_pin": "<:maps_historic_cn_pin:1307492779211096204>",
  "maps_historic_pin": "<:maps_historic_pin:1307492790988574750>",
  "maps_hospital_pin": "<:maps_hospital_pin:1307492801147310111>",
  "maps_hotspring_pin": "<:maps_hotspring_pin:1307492810987147299>",
  "maps_library_pin": "<:maps_library_pin:1307492821879492770>",
  "maps_lighthouse_pin": "<:maps_lighthouse_pin:1307492833837580338>",
  "maps_lodging_pin": "<:maps_lodging_pin:1307492844952358922>",
  "maps_medical_pin": "<:maps_medical_pin:1307492856872566896>",
  "maps_monument_pin": "<:maps_monument_pin:1307492867627028511>",
  "maps_mountain_pin": "<:maps_mountain_pin:1307492876674138243>",
  "maps_movie_pin": "<:maps_movie_pin:1307492902561382410>",
  "maps_museum_jp_pin": "<:maps_museum_jp_pin:1307492943220703352>",
  "maps_museum_pin": "<:maps_museum_pin:1307493021268574349>",
  "maps_note_pin": "<:maps_note_pin:1307493031485902950>",
  "maps_palette_pin": "<:maps_palette_pin:1307493053287890964>",
  "maps_parking_pin": "<:maps_parking_pin:1307493063786238042>",
  "maps_paw_pin": "<:maps_paw_pin:1307493075609981020>",
  "maps_pharmacy_pin": "<:maps_pharmacy_pin:1307493086586212532>",
  "maps_police_jp_pin": "<:maps_police_jp_pin:1307493097726410802>",
  "maps_police_pin": "<:maps_police_pin:1307493109365608528>",
  "maps_postoffice_jp_pin": "<:maps_postoffice_jp_pin:1307493121340215316>",
  "maps_postoffice_pin": "<:maps_postoffice_pin:1307493134158266429>",
  "maps_relic_jp_pin": "<:maps_relic_jp_pin:1307493185194561577>",
  "maps_resort_pin": "<:maps_resort_pin:1307493196099747911>",
  "maps_restaurant_pin": "<:maps_restaurant_pin:1307493206493237348>",
  "maps_restroom_pin": "<:maps_restroom_pin:1307493216916082698>",
  "maps_school_pin": "<:maps_school_pin:1307493226734948393>",
  "maps_shopping_pin": "<:maps_shopping_pin:1307493252462678107>",
  "maps_shoppingcart_pin": "<:maps_shoppingcart_pin:1307493264848453652>",
  "maps_stadium_pin": "<:maps_stadium_pin:1307493275812237372>",
  "maps_street_pin": "<:maps_street_pin:1307493286067306576>",
  "maps_theater_pin": "<:maps_theater_pin:1307493296096149505>",
  "maps_transit_pin": "<:maps_transit_pin:1307493312693010492>",
  "maps_tree_pin": "<:maps_tree_pin:1307493327658291281>",
  "maps_worship_buddhist_pin": "<:maps_worship_buddhist_pin:1307493338156503131>",
  "maps_worship_christian_pin": "<:maps_worship_christian_pin:1307493348688396408>",
  "maps_worship_dharma_pin": "<:maps_worship_dharma_pin:1307493368028201020>",
  "maps_worship_hindu_pin": "<:maps_worship_hindu_pin:1307493380053270608>",
  "maps_worship_jain_pin": "<:maps_worship_jain_pin:1307493390987821117>",
  "maps_worship_jewish_pin": "<:maps_worship_jewish_pin:1307493402396459091>",
  "maps_worship_mormon_pin": "<:maps_worship_mormon_pin:1307493432834392087>",
  "maps_worship_shinto_pin": "<:maps_worship_shinto_pin:1307493443693707356>",
  "maps_worship_sikh_pin": "<:maps_worship_sikh_pin:1307493454053376020>",
  "maps_worship_temple_pin": "<:maps_worship_temple_pin:1307493467793915924>",

  /* Various Brand Icons */
  "brand_google_gemini": "<:brand_google_gemini:1320506533003530270>",
  "brand_google_palm2": "<:brand_google_palm2:1321959401376186492>",

  "information": "<:ico_information:1263590946226835510>",
  "question": "<:ico_question:1263590898906697800>",
  "warning": "<:ico_warning:1263590857072967832>",

  // Internal Icons
  "empty": "<:ico_empty:1263591098740113478>",

  // Legacy Icon Compat
  "success_simple": "<:ico_check:1263594912692178974>",
  "failiure_simple": "<:ico_cross:1263594899048235100>",

  /*
    Webhook Icons

    These emoji are located on the
    china (682672131359637534) server
    since webhooks can't access bot-owned emoji.
  */
  "webhook_exclaim_0": "<:ico_exclaim_0:1321960522547068938>",
  "webhook_exclaim_1": "<:ico_exclaim_1:1321960524300292146> ",
  "webhook_exclaim_2": "<:ico_exclaim_2:1321960526162694225> ",
  "webhook_exclaim_3": "<:ico_exclaim_3:1321960528058253524> ",
  "webhook_exclaim_4": "<:ico_exclaim_4:1321960529811738776>",
})

module.exports.MUSIC_PLATFORM_ICONS = Object.freeze({
  "amazonStore": "1271168898603159554",
  "amazonMusic": "1271168908182945842",
  "appleMusic": "1271168916810498131",
  "deezer": "1271168925652095097",
  "itunes": "1271168933495574582",
  "napster": "1271168944094318673",
  "pandora": "1271168950784491601",
  "soundcloud": "1271168959814832160",
  "spotify": "1271168976755363840",
  "tidal": "1271169001158082624",
  "youtube": "1297690069485879337",
  "youtubeMusic": "1297690078612553748"
})

module.exports.COMPONENT_BUTTON_ICONS = Object.freeze({
  NEXT: this.ICONS.button_chevron_right,
  PREVIOUS: this.ICONS.button_chevron_left,
  STOP: this.ICONS.button_trash,
  SEARCH: this.ICONS.button_mag,
  UNKNOWN: this.ICONS.question_large
})

module.exports.GUILD_FEATURE_ICONS_REDESIGN = Object.freeze({
  "ActivitiesIcon": "<:ico_d_activities:1263595238929334272>",
  "AnnouncementsIcon": "<:ico_d_announcements:1263595270684545205>",
  "BadgeIcon": "<:ico_d_badge:1263595290363957342>",
  "BeakerIcon": "<:ico_d_beaker:1263595306184867840>",
  "BillIcon": "<:ico_d_bill:1263595324090482719>",
  "BoostTier3Icon": "<:iico_d_boosttier3:1263595349667352668>",
  "BrowserIcon": "<:ico_d_browser:1263595374778515649>",
  "ChatArrowRightIcon": "<:ico_d_chatarrowrighticon:1362501997697171487>",
  "CircleQuestionIcon": "<:ico_d_circlequestion:1263595522921337025>",
  "ClansIcons": "<:ico_d_clans:1271207373650006117>",
  "ClockWarningIcon": "<:ico_d_clockwarning:1263595576520474714>",
  "CompassIcon": "<:ico_d_compass:1263595614122409984>",
  "FileUpIcon": "<:ico_d_fileupicon:1362499096518201364>",
  "ForumIcon": "<:ico_d_forum:1263595652680650824> ",
  "GameControllerIcon": "<:ico_d_gamecontroller:1263595688323846225>",
  "GifIcon": "<:ico_d_gif:1263595715129643129>",
  "GlobeEarthIcon": "<:ico_d_globeearth:1263595760054960161>",
  "GroupIcon": "<:ico_d_group:1263595799275770007>",
  "HeadphonesIcon": "<:ico_d_headphonesicon:1362498276447752435>",
  "HomeIcon": "<:ico_d_home:1263596088821026938>",
  "HubIcon": "<:ico_d_hub:1263596112229568512>",
  "ImageIcon": "<:ico_d_imageicon:1362502720635797555>",
  "ImagesIcon": "<:ico_d_images:1263596134061051935>",
  "LinkIcon": "<:ico_d_link:1263596153434407032>",
  "NewUserLargeIcon": "<:ico_d_newuserlarge:1263596178725933137>",
  "PaintbrushThickIcon": "<:ico_d_paintbrushthick:1263596221524869164>",
  "PartnerIcon": "<:ico_dc_partnerflowerbadge:1263601192643199077>",
  "PencilSparkleIcon": "<:ico_d_pencilsparkleicon:1362500937859596419>",
  "PiggyBankIcon": "<:ico_d_piggybank:1263596275853688944>",
  "ReactionIcon": "<:ico_d_reaction:1263596296544194703>",
  "RobotIcon": "<:ico_d_robot:1263596312314777782>",
  "ServerIcon": "<:ico_d_server:1263596330400354314>",
  "ShieldIcon": "<:ico_d_shield:1263596397924712570>",
  "ShieldUserIcon": "<:ico_d_shielduser:1263596413829386292>",
  "SignPostIcon": "<:ico_d_signpost:1263596376554737674>",
  "SlashBoxIcon": "<:ico_d_slashbox:1263596429432328273>",
  "SoundboardIcon": "<:ico_d_soundboard:1263596446301683825>",
  "SparklesIcon": "<:ico_d_sparkles:1263596462764462192>",
  "StaffBadgeIcon": "<:ico_d_staffbadge:1263596482519502868>",
  "StageIcon": "<:ico_d_stageicon:1362498165202227270>",
  "SuperReactionIcon": "<:ico_d_superreaction:1263596497283579957>",
  "TagIcon": "<:ico_d_tag:1263596510994501745>",
  "TextIcon": "<:ico_d_text:1263596525288685579>",
  "ThreadIcon": "<:ico_d_thread:1263596544486146068>",
  "TicketIcon": "<:ico_d_ticket:1263596560172716103>",
  "TopicsIcon": "<:ico_d_topics:1263596574978867240>",
  "TreehouseIcon": "<:ico_d_treehouse:1263596587763105843>",
  "UserIcon": "<:ico_d_user:1263596600891281510>",
  "UserPlusIcon": "<:ico_d_userplus:1263596620059246752>",
  "UserShieldIcon": "<:ico_d_usershield:1263596641450066051>",
  "VerifiedIcon": "<:ico_dc_verifiedflowerbadge:1263600898685272184>",
  "VideoIcon": "<:ico_d_videoicon:1362498220994855077>",
  "VoiceIcon": "<:ico_d_voicenormal:1263596678087446548>",
})

// This list should be synced with https://docs.discord.sex/resources/guild#guild-features
module.exports.GUILD_FEATURES = Object.freeze({
  "ACTIVITIES_ALPHA": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ActivitiesIcon },
  "ACTIVITIES_EMPLOYEE": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ActivitiesIcon },
  "ACTIVITIES_INTERNAL_DEV": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ActivitiesIcon },
  "ACTIVITY_FEED_DISABLED_BY_USER": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.GameControllerIcon },
  "ACTIVITY_FEED_ENABLED_BY_USER": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.GameControllerIcon },
  "ANIMATED_BANNER": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.GifIcon },
  "ANIMATED_ICON": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.GifIcon },
  "APPLICATION_COMMAND_PERMISSIONS_V2": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.SlashBoxIcon, label: "New Slash Command Permissions" },
  "AUDIO_BITRATE_128_KBPS": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.HeadphonesIcon, label: "Audio Bitrate 128kbps" },
  "AUDIO_BITRATE_256_KBPS": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.HeadphonesIcon, label: "Audio Bitrate 256kbps" },
  "AUDIO_BITRATE_384_KBPS": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.HeadphonesIcon, label: "Audio Bitrate 384kbps" },
  "AUTO_MODERATION": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ShieldIcon, label: "Automod" },
  "AUTOMOD_TRIGGER_KEYWORD_FILTER": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ShieldIcon },
  "AUTOMOD_TRIGGER_ML_SPAM_FILTER": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ShieldIcon },
  "AUTOMOD_TRIGGER_SPAM_LINK_FILTER": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ShieldIcon },
  "AUTOMOD_TRIGGER_USER_PROFILE": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ShieldIcon },
  "BANNER": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ImagesIcon, label: "Server Banner" },
  "BFG": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ServerIcon, label: "Really Big Server" },
  "BOOSTING_TIERS_EXPERIMENT_MEDIUM_GUILD": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.BoostTier3Icon },
  "BOOSTING_TIERS_EXPERIMENT_SMALL_GUILD": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.BoostTier3Icon },
  "BOT_DEVELOPER_EARLY_ACCESS": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.RobotIcon },
  "BURST_REACTIONS": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.SuperReactionIcon },
  "CHANNEL_BANNER": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ImagesIcon },
  "CHANNEL_EMOJIS_GENERATED": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ReactionIcon },
  "CHANNEL_HIGHLIGHTS": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.SparklesIcon },
  "CHANNEL_HIGHLIGHTS_DISABLED": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.SparklesIcon },
  "CHANNEL_ICON_EMOJIS_GENERATED": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ReactionIcon },
  "CLAN": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ClansIcons },
  "CLAN_DISCOVERY_DISABLED": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ClansIcons },
  "CLAN_PILOT_GENSHIN": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ClansIcons },
  "CLAN_PILOT_VALORANT": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ClansIcons },
  "CLAN_PREPILOT_GENSHIN": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ClansIcons },
  "CLAN_PREPILOT_VALORANT": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ClansIcons },
  "CLAN_SAFETY_REVIEW_DISABLED": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ClansIcons },
  "CLYDE_DISABLED": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.RobotIcon },
  "CLYDE_ENABLED": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.RobotIcon },
  "CLYDE_EXPERIMENT_ENABLED": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.RobotIcon },
  "COMMERCE": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.TagIcon, label: "Store Channels" },
  "COMMUNITY": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.TreehouseIcon },
  "COMMUNITY_CANARY": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.TreehouseIcon },
  "COMMUNITY_EXP_LARGE_GATED": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.TreehouseIcon, label: "Communities, Large Gated Server" },
  "COMMUNITY_EXP_LARGE_UNGATED": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.TreehouseIcon, label: "Communities, Large Ungated Server" },
  "COMMUNITY_EXP_MEDIUM": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.TreehouseIcon, label: "Communities, Medium Server" },
  "CREATOR_ACCEPTED_NEW_TERMS": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.BillIcon },
  "CREATOR_MONETIZABLE": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.BillIcon },
  "CREATOR_MONETIZABLE_DISABLED": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.BillIcon },
  "CREATOR_MONETIZABLE_PENDING_NEW_OWNER_ONBOARDING": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.BillIcon },
  "CREATOR_MONETIZABLE_PROVISIONAL": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.BillIcon },
  "CREATOR_MONETIZABLE_RESTRICTED": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.BillIcon },
  "CREATOR_MONETIZABLE_WHITEGLOVE": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.BillIcon },
  "CREATOR_MONETIZATION_APPLICATION_ALLOWLIST": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.BillIcon },
  "CREATOR_STORE_PAGE": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.BrowserIcon },
  "DEVELOPER_SUPPORT_SERVER": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.RobotIcon },
  "DISCOVERABLE": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.CompassIcon },
  "DISCOVERABLE_DISABLED": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.CompassIcon },
  "ENABLED_DISCOVERABLE_BEFORE": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.CompassIcon, label: "Discovery previously enabled" },
  "ENABLED_MODERATION_EXPERIENCE_FOR_NON_COMMUNITY": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ShieldIcon },
  "ENHANCED_ROLE_COLORS": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.PencilSparkleIcon, label: "Gradient Role Colors" },
  "EXPOSED_TO_ACTIVITIES_WTP_EXPERIMENT": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ActivitiesIcon },
  "EXPOSED_TO_BOOSTING_TIERS_EXPERIMENT": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.BoostTier3Icon },
  "FEATURABLE": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.CompassIcon },
  "FORCE_RELAY": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ServerIcon, label: "Relay force enabled" },
  "FORWARDING_DISABLED": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ChatArrowRightIcon },
  "GENSHIN_L30": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ClansIcons },
  "GUESTS_ENABLED": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.GroupIcon },
  "GUILD_AUTOMOD_DEFAULT_LIST": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ShieldIcon , label: "Automod default list"},
  "GUILD_COMMUNICATION_DISABLED_GUILDS": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ClockWarningIcon, label: "Timeouts enabled" },
  "GUILD_HOME_DEPRECATION_OVERRIDE": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.HomeIcon, label: "Home Deprecation Override" },
  "GUILD_HOME_OVERRIDE": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.HomeIcon, label: "Home Override" },
  "GUILD_HOME_TEST": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.HomeIcon, label: "Home Test" },
  "GUILD_MEMBER_VERIFICATION_EXPERIMENT": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.UserShieldIcon },
  "GUILD_ONBOARDING": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.NewUserLargeIcon, label: "Onboarding" },
  "GUILD_ONBOARDING_ADMIN_ONLY": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.NewUserLargeIcon, label: "Onboarding admin only" },
  "GUILD_ONBOARDING_EVER_ENABLED": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.NewUserLargeIcon, label: "Onboarding previously enabled" },
  "GUILD_ONBOARDING_HAS_PROMPTS": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.NewUserLargeIcon, label: "Onboarding has prompts" },
  "GUILD_PRODUCTS": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.PiggyBankIcon, label: "Server Products" },
  "GUILD_PRODUCTS_ALLOW_ARCHIVED_FILE": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.PiggyBankIcon, label: "Server Products: Archive Files" },
  "GUILD_ROLE_SUBSCRIPTIONS": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.BadgeIcon, label: "Role Subscriptions" },
  "GUILD_ROLE_SUBSCRIPTION_PURCHASE_FEEDBACK_LOOP": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.BadgeIcon, label: "Role Subscriptions Feedback" },
  "GUILD_ROLE_SUBSCRIPTION_TIER_TEMPLATE": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.BadgeIcon, label: "Role Subscriptions Tier Template" },
  "GUILD_ROLE_SUBSCRIPTION_TRIALS": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.BadgeIcon, label: "Role Subscriptions Trials" },
  "GUILD_SERVER_GUIDE": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.SignPostIcon, label: "Server Guide" },
  "GUILD_TAGS": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.TagIcon, label: "Server Tags" },
  "GUILD_WEB_PAGE_VANITY_URL": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.GlobeEarthIcon, label: "Server Web Page Vanity URL" },
  "HAD_EARLY_ACTIVITIES_ACCESS": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ActivitiesIcon },
  "HAS_DIRECTORY_ENTRY": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.HubIcon },
  "HIDE_FROM_EXPERIMENT_UI": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.BeakerIcon },
  "HUB": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.HubIcon, label: "Student Hub" },
  "INCREASED_THREAD_LIMIT": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ThreadIcon },
  "INTERNAL_EMPLOYEE_ONLY": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.StaffBadgeIcon },
  "INVITES_DISABLED": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.LinkIcon },
  "INVITE_SPLASH": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ImagesIcon },
  "LEADERBOARD_ENABLED": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.BeakerIcon },
  "LINKED_TO_HUB": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.HubIcon },
  "LURKABLE": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.CompassIcon },
  "MARKETPLACES_CONNECTION_ROLES": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ShieldUserIcon },
  "MAX_FILE_SIZE_50_MB": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.FileUpIcon },
  "MAX_FILE_SIZE_100_MB": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.FileUpIcon },
  "MEDIA_CHANNEL_ALPHA ": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ImageIcon },
  "MEMBER_LIST_DISABLED": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.GroupIcon },
  "MEMBER_PROFILES": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.UserIcon },
  "MEMBER_SAFETY_PAGE_ROLLOUT": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.GroupIcon },
  "MEMBER_VERIFICATION_GATE_ENABLED": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.UserShieldIcon, label: "Membership Screening" },
  "MEMBER_VERIFICATION_MANUAL_APPROVAL": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.UserShieldIcon, label: "Membership Screening Manual Approval" },
  "MEMBER_VERIFICATION_ROLLOUT_TEST": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.UserShieldIcon },
  "MOBILE_WEB_ROLE_SUBSCRIPTION_PURCHASE_PAGE": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.BrowserIcon, label: "Role Subscriptions Web Page enabled" },
  "MONETIZATION_ENABLED": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.BillIcon },
  "MORE_EMOJI": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ReactionIcon },
  "MORE_STICKERS": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ReactionIcon },
  "NEWS": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.AnnouncementsIcon, label: "Announcement Channels" },
  "NEW_THREAD_PERMISSIONS": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ThreadIcon },
  "NON_COMMUNITY_RAID_ALERTS": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ShieldIcon },
  "PARTNERED": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.PartnerIcon },
  "PREMIUM_TIER_3_OVERRIDE": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.BoostTier3Icon },
  "PREVIEW_ENABLED": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.CompassIcon },
  "PRIVATE_THREADS": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ThreadIcon },
  "PRODUCTS_AVAILABLE_FOR_PURCHASE": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.TagIcon },
  "PUBLIC": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.CompassIcon },
  "PUBLIC_DISABLED": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.CompassIcon },
  "RAID_ALERTS_DISABLED": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ShieldIcon },
  "RAID_ALERTS_ENABLED": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ShieldIcon },
  "RAPIDASH_TEST": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ClansIcons },
  "RELAY_ENABLED": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ServerIcon },
  "RESTRICT_SPAM_RISK_GUILDS": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.UserShieldIcon },
  "ROLE_ICONS": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ShieldUserIcon },
  "ROLE_SUBSCRIPTIONS_AVAILABLE_FOR_PURCHASE": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.BadgeIcon },
  "ROLE_SUBSCRIPTIONS_ENABLED": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.BadgeIcon },
  "ROLE_SUBSCRIPTIONS_ENABLED_FOR_PURCHASE": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.BadgeIcon },
  "SERVER_PROFILES_TEST": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ServerIcon },
  "SEVEN_DAY_THREAD_ARCHIVE": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ThreadIcon },
  "SHARD": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ServerIcon },
  "SHARED_CANVAS_FRIENDS_AND_FAMILY_TEST": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.PaintbrushThickIcon },
  "SOUNDBOARD": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.SoundboardIcon },
  "SUMMARIES_DISABLED_BY_USER": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.TopicsIcon },
  "STAFF_LEVEL_COLLABORATOR_REQUIRED": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.StaffBadgeIcon },
  "STAFF_LEVEL_RESTRICTED_COLLABORATOR_REQUIRED": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.StaffBadgeIcon },
  "STAGE_CHANNEL_VIEWERS_50": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.StageIcon },
  "STAGE_CHANNEL_VIEWERS_150": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.StageIcon },
  "STAGE_CHANNEL_VIEWERS_300": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.StageIcon },
  "SUMMARIES_ENABLED": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.TopicsIcon },
  "SUMMARIES_ENABLED_BY_USER": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.TopicsIcon },
  "SUMMARIES_ENABLED_GA": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.TopicsIcon },
  "SUMMARIES_LONG_LOOKBACK": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.TopicsIcon },
  "SUMMARIES_OPT_OUT_EXPERIENCE": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.TopicsIcon },
  "TEXT_IN_STAGE_ENABLED": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.TextIcon },
  "TEXT_IN_VOICE_ENABLED": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.TextIcon },
  "THREADS_ENABLED": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ThreadIcon },
  "THREADS_ENABLED_TESTING": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ThreadIcon },
  "THREADS_ONLY_CHANNEL": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ForumIcon, label: "Forum Channels" },
  "THREAD_DEFAULT_AUTO_ARCHIVE_DURATION": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ThreadIcon },
  "THREE_DAY_THREAD_ARCHIVE": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ThreadIcon },
  "TICKETED_EVENTS_ENABLED": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.TicketIcon },
  "TICKETING_ENABLED": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.TicketIcon },
  "TIERLESS_BOOSTING": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.BoostTier3Icon, label: "New Boosting" },
  "TIERLESS_BOOSTING_TEST": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.BeakerIcon, label: "New Boosting Testing" },
  "VALORANT_L30": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ClansIcons },
  "VANITY_URL": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.GlobeEarthIcon },
  "VERIFIED": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.VerifiedIcon },
  "VIDEO_BITRATE_ENHANCED": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.VideoIcon },
  "VIDEO_QUALITY_1080_60FPS": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.VideoIcon },
  "VIDEO_QUALITY_720_60FPS": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.VideoIcon },
  "VIP_REGIONS": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.VoiceIcon },
  "VOICE_CHANNEL_EFFECTS": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.VoiceIcon },
  "VOICE_IN_THREADS": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.ThreadIcon },
  "WELCOME_SCREEN_ENABLED": { icon: this.GUILD_FEATURE_ICONS_REDESIGN.UserPlusIcon },
})

module.exports.FUNNY_CAT_ICONS = [
  "<:ico_garf_gm:1263608611645558814>",
  "<:ico_garf_gn:1263608597179404319>",
  "<:ico_garf_funnycat:1263608584390971498>",
  "<:ico_garf_garthumbsup:1263608571929694353>"
]

module.exports.TIKTOK_VOICES_FRENCH = {
  "fr_001": "French Male 1",
  "fr_002": "French Male 2"
}

module.exports.TIKTOK_VOICES_GERMAN = {
  "de_001": "German Female",
  "de_002": "German Male"
}

module.exports.TIKTOK_VOICES_INDONESIAN = {
  "id_male_darma": "Darma",
  "id_female_icha": "Icha",
  "id_female_noor": "Noor",
  "id_male_putra": "Putra"
}

module.exports.TIKTOK_VOICES_ITALIAN = {
  "it_male_m18": "Italian Male"
}

module.exports.TIKTOK_VOICES_JAPANESE = {
  "jp_001": "Miho (美穂)",
  "jp_003": "Keiko (恵子)",
  "jp_005": "Sakura (さくら)",
  "jp_006": "Naoki (直樹)",
  "jp_male_osada": "モリスケ (Morisuke)",
  "jp_male_matsuo": "モジャオ (Matsuo)",
  "jp_female_machikoriiita": "まちこりーた (Machikoriiita)",
  "jp_male_matsudake": " マツダ家の日常 (Matsudake)",
  "jp_male_shuichiro": "修一朗 (Shuichiro)",
  "jp_female_rei": "丸山礼 (Maruyama Rei)",
  "jp_male_hikakin": "ヒカキン (Hikakin)",
  "jp_female_yagishaki": "八木沙季 (Yagi Saki)",
}

module.exports.TIKTOK_VOICES_KOREAN = {
  "kr_002": "Korean Male 1",
  "kr_004": "Korean Male 2",
  "kr_003": "Korean Female"
}

module.exports.TIKTOK_VOICES_PORTUGESE = {
  "br_003": "Júlia",
  "br_004": "Ana",
  "br_005": "Lucas",
  "pt_female_lhays": "Lhays Macedo",
  "pt_female_laizza": "Laizza",
}

module.exports.TIKTOK_VOICES_SPANISH = {
  "es_002": "Spanish Male",
  "es_male_m3": "Julio",
  "es_female_f6": "Alejandra",
  "es_female_pb1": "Mariana",
  "es_mx_002": "Álex (Warm)",
  "es_mx_female_supermom": "Super Mamá",
}

module.exports.TIKTOK_VOICES_SONG = {
  "en_male_m2_xhxs_m03_silly": "Song: Quirky Time",
  "en_female_f08_twinkle": "Song: Pop Lullaby",
  "en_male_m03_sunshine_soon": "Song: Toon Beat (Sunshine Soon)",
  "en_male_sing_funny_thanksgiving": "Song: Thanksgiving",
  "en_female_ht_f08_newyear": "Song: NYE 2023",
  "en_female_ht_f08_wonderful_world": "Song: Melodrama (Wonderful World)",
  "en_male_m03_lobby": "Song: Jingle (Lobby)",
  "en_male_sing_funny_it_goes_up": "Song: Hypetrain (It Goes Up)",
  "en_female_ht_f08_glorious": "Song: Euphoric (Glorious)",
  "en_female_ht_f08_halloween": "Song: Opera (Halloween)",
  "en_female_f08_warmy_breeze": "Song: Open Mic (Warmy Breeze)",
  "en_male_m2_xhxs_m03_christmas": "Song: Cozy",
  "en_female_f08_salut_damour": "Song: Cottagecore (Salut d'Amour)",
  "en_male_m03_classical": "Song: Classic Electric",
  "en_male_sing_deep_jingle": "Song: Caroler",
}

module.exports.TIKTOK_VOICES_POP_CULTURE = {
  "en_female_madam_leota": "Madame Leota (Haunted Mansion)",
  "en_us_rocket": "Rocket (Guardians of the Galaxy)",
  "en_us_stitch": "Stitch (Lilo & Stitch)",
  "en_us_stormtrooper": "Stormtrooper (Star Wars)",
  "en_us_c3po": "C-3PO (Star Wars)",
  "en_us_chewbacca": "Chewbacca (Star Wars)",
  "en_us_ghostface": "Ghostface (Scream)",
  "en_male_grinch": "Trickster (Grinch)",
  "en_male_ghosthost": "Ghost Host",
  "en_male_ukbutler": "Mr. Meticulous",
  "en_male_deadpool": "Mr. GoodGuy (Deadpool)",
//"en_male_petercullen": "Optimus Prime",
}

module.exports.TIKTOK_VOICES_CHARACTERS = {
  "en_female_pansino": "Varsity",
//"en_male_santa_effect": "Santa (w/ effect)",
  "en_male_santa": "Santa",
  "en_male_pirate": "Pirate",
  "en_male_trevor": "Marty",
  "en_male_wizard": "Magician",
  "en_male_ukneighbor": "Lord Cringe",
  "en_female_grandma": "Grandma",
  "en_female_shenna": "Debutante",
  "en_male_cupid": "Cupid",
//"en_female_richgirl": "Bestie",
  "en_female_makeup": "Beauty Guru",
  "en_female_betty": "Bae",
//"en_male_santa_narration": "Author",
  "en_male_jarvis": "Alfred",
  "en_male_funny": "Wacky",
  "en_male_narration": "Story Teller",
  "en_male_cody": "Serious",
  "en_female_samc": "Empathetic",
  "en_us_010": "Confidence",
  "en_us_009": "Scientist",
  "en_us_007": "Professor",
  "en_us_006": "Joey",
  "en_us_002": "Jessie",
  "en_au_002": "Smooth (Alex)",
  "en_au_001": "Metro (Eddie)",
  "en_female_emotional": "Peaceful",
  "en_uk_001": "Narrator (Chris)",
}

module.exports.TIKTOK_VOICES = [
  { name: "English Singing - Tenor", value: "en_male_m03_lobby" },
  { name: "English Singing - Alto", value: "en_female_f08_salut_damour" },
  { name: "English Singing - Warmy Breeze", value: "en_female_f08_warmy_breeze" },
  { name: "English Singing - Sunshine Soon", value: "en_male_m03_sunshine_soon" },
  { name: "English Narration - Normal", value: "en_male_narration" },
  { name: "English Narration - Funny", value: "en_male_funny" },
  { name: "English Narration - Emotional", value: "en_female_emotional" },
  { name: "English AU - Female", value: "en_au_001" },
  { name: "English AU - Male", value: "en_au_002" },
  { name: "English UK - Male", value: "en_uk_001" },
  { name: "English US - Female", value: "en_us_001" },
  { name: "English US - Male", value: "en_us_006" },
  { name: "Ghost Face (Disney)", value: "en_us_ghostface" },
  { name: "Chewbacca (Disney)", value: "en_us_chewbacca" },
  { name: "C3PO (Disney)", value: "en_us_c3po" },
  { name: "Stitch (Disney)", value: "en_us_stitch" },
  { name: "Stormtrooper (Disney)", value: "en_us_stormtrooper" },
  { name: "Rocket (Disney)", value: "en_us_rocket" },
  { name: "French - Male", value: "fr_001" },
  { name: "German - Female", value: "de_001" },
  { name: "German - Male", value: "de_002" },
  { name: "Spanish - Male", value: "es_002" },
  { name: "Spanish MX - Male", value: "es_mx_002" }
]

module.exports.PLAYHT_VOICES = [
  { name: "Conrad (German)", value: "de-DE-ConradNeural" }
]

module.exports.IMTRANSLATOR_VOICES = [
  { name: "English (Male)", value: "en" },
  { name: "English (Female)", value: "enf" },
  { name: "Chinese (Female)", value: "zh" },
  { name: "Spanish (Carlos)", value: "es" },
  { name: "Russian (Female)", value: "ru" },
  { name: "French (Female)", value: "fr" },
  { name: "German (Male)", value: "de" },
  { name: "Italian (Male)", value: "it" },
  { name: "Portugese (Female)", value: "pt" },
  { name: "Japanese (Female)", value: "ja" },
  { name: "Korean (Female)", value: "ko" }
]

module.exports.MICROSOFT_VOICES = [
  { name: "Microsoft Sam", value: "Sam" },
  { name: "BonziBUDDY", value: "Bonzi" },
  { name: "Mary", value: "Mary" },
  { name: "Mike", value: "Mike" },
  { name: "Robot", value: "RoboSoft Four" },
  { name: "Whisper (Female)", value: "Female Whisper" },
  { name: "Whisper (Male)", value: "Male Whisper" }
]

module.exports.MICROSOFT_VOICE_CONFIG = {
  "Sam": { pitch: 100, speed: 150 },
  "Bonzi": { pitch: 140, speed: 157 },
  "Mary": { pitch: 169, speed: 170 },
  "Mike": { pitch: 113, speed: 170 },
  "RoboSoft Four": { pitch: 169, speed: 170 },
  "Female Whisper": { pitch: 169, speed: 170 },
  "Male Whisper": { pitch: 113, speed: 170 }
}

module.exports.REWRITE_STYLES = [
  { name: "📝 Fix Grammar", value: "GRAMMAR" },
  { name: "🤩 Excited", value: "EXCITED" },
  { name: "😎 Chill", value: "CHILL" },
  { name: "📜 Shakespeare", value: "SHAKESPEARE" },
  { name: "📰 Shorten", value: "SHORTEN" },
  { name: "📄 Formal", value: "FORMAL" }
]


module.exports.DICTIONARY_LANGUAGES = Object.freeze({
  ar: "Arabic",
  ca: "Catalan",
  cs: "Czech",
  da: "Danish",
  de: "German",
  el: "Greek",
  "en-uk": "English (UK)",
  en: "English (US)",
  es: "Spanish",
  fi: "Finnish",
  fr: "French",
  hi: "Hindi",
  hr: "Croatian",
  id: "Indonesian",
  it: "Italian",
  iw: "Hebrew",
  ja: "Japanese",
  ko: "Korean",
  nl: "Dutch",
  no: "Norwegian",
  pl: "Polish",
  "pt-br": "Portuguese (Brazil)",
  "pt-pt": "Portuguese (Portugal)",
  pt: "Portuguese",
  ro: "Romanian",
  ru: "Russian",
  sr: "Serbian",
  sk: "Slovak",
  sv: "Swedish",
  th: "Thai",
  tl: "Tagalog",
  tr: "Turkish",
  uk: "Ukrainian",
  vi: "Vietnamese",
  "zh-cn": "Chinese",
  "zh-tw": "Chinese",
  zh: "Chinese"
})

// Default list of languages uses in various translate contexts
module.exports.TRANSLATE_DEFAULT_LANGUAGE_LIST = Object.freeze([
  "en",
  "de",
  "fr",
  "es",
  "pt-PT",
  "no",
  "fi",
  "sv",
  "it",
  "ja",
  "ru",
  "ar",
  "he",
  "tr",
  "hi",
  "zh-CN",
  "zh-TW",
])

module.exports.TRANSLATE_AUTOCOMPLETE_HIDDEN_LANGUAGES = Object.freeze([
  "ja-Latn"
])

// hey if you're looking at this and are annoyed that a language
// doesn't as expected work lmk on discord @bignutty and i'll add
// it (within reason), same goes for flag emoji below
module.exports.TRANSLATE_LANGUAGE_ALIASES = Object.freeze({
  "jp": "ja",
})

// there are a lot of overlapping flags (specifically in eastern territories),
// we have separata "display" and "resolve" mappings now.
module.exports.TRANSLATE_DISPLAY_MAPPINGS = Object.freeze({
  "auto": this.ICONS_NEXTGEN.gs_auto_awesome,
  "und": this.ICONS_NEXTGEN.gs_auto_awesome,
  "af": "🇿🇦",
  "sq": "🇦🇱",
  "am": "🇪🇹",
  "ar": "🇸🇦",
  "hy": "🇦🇲",
  "as": "🇮🇳",
  "ay": "🇧🇴",
  "az": "🇦🇿",
  "bm": "🇲🇱",
  "eu": "",
  "be": "🇧🇾",
  "bn": "🇧🇩",
  "bho": "🇮🇳",
  "bs": "🇧🇦",
  "bg": "🇧🇬",
  "ca": "",
  "ceb": "🇵🇭",
  "co": "",
  "hr": "🇭🇷",
  "cs": "🇨🇿",
  "da": "🇩🇰",
  "dv": "🇲🇻",
  "doi": "🇮🇳",
  "nl": "🇳🇱",
  "en": "🇺🇸",
  "eo": "",
  "et": "🇪🇪",
  "ee": "🇹🇬",
  "fil": "🇵🇭",
  "fi": "🇫🇮",
  "fr": "🇫🇷",
  "fy": "🇳🇱",
  "gl": "🇪🇸",
  "ka": "🇬🇪",
  "de": "🇩🇪",
  "el": "🇬🇷",
  "gn": "🇵🇾",
  "gu": "🇮🇳",
  "ht": "🇭🇹",
  "ha": "🇳🇬",
  "haw": "",
  "he": "🇮🇱",
  "iw": "🇮🇱",
  "hi": "🇮🇳",
  "hmn": "",
  "hu": "🇭🇺",
  "is": "🇮🇸",
  "ig": "🇳🇬",
  "ilo": "",
  "id": "🇮🇩",
  "ga": "🇮🇪",
  "it": "🇮🇹",
  "ja": "🇯🇵",
  "ja-Latn": "🇯🇵",
  "jv": "🇮🇩",
  "kn": "🇮🇳",
  "kk": "🇰🇿",
  "km": "🇰🇭",
  "rw": "🇷🇼",
  "gom": "🇮🇳",
  "ko": "🇰🇷",
  "kri": "🇸🇱",
  "ku": "",
  "ckb": "",
  "ky": "🇰🇬",
  "lo": "🇱🇦",
  "la": "",
  "lv": "🇱🇻",
  "ln": "🇨🇩",
  "lt": "🇱🇹",
  "lg": "🇺🇬",
  "lb": "🇱🇺",
  "mk": "🇲🇰",
  "mai": "🇮🇳",
  "mg": "🇲🇬",
  "ms": "🇲🇾",
  "ml": "🇮🇳",
  "mt": "🇲🇹",
  "mi": "🇳🇿",
  "mr": "🇮🇳",
  "mn": "🇲🇳",
  "my": "🇲🇲",
  "ne": "🇳🇵",
  "no": "🇳🇴",
  "ny": "🇲🇼",
  "ps": "🇦🇫",
  "fa": "🇮🇷",
  "pl": "🇵🇱",
  "pt": "🇵🇹",
  "pt-pt": "🇵🇹",
  "pt-br": "🇧🇷",
  "ro": "🇷🇴",
  "ru": "🇷🇺",
  "sm": "🇼🇸",
  "sa": "🇮🇳",
  "gd": "",
  "nso": "🇿🇦",
  "sr": "🇷🇸",
  "st": "🇱🇸",
  "sn": "🇿🇼",
  "si": "🇱🇰",
  "sk": "🇸🇰",
  "sl": "🇸🇮",
  "so": "🇸🇴",
  "es": "🇪🇸",
  "su": "🇸🇩",
  "sw": "🇰🇪",
  "sv": "🇸🇪",
  "tl": "🇵🇭",
  "tg": "🇹🇯",
  "te": "🇮🇳",
  "th": "🇹🇭",
  "ti": "🇪🇷",
  "ts": "🇹🇴",
  "tr": "🇹🇷",
  "tk": "🇹🇲",
  "ak": "🇬🇭",
  "uk": "🇺🇦",
  "ur": "🇵🇰",
  "uz": "🇺🇿",
  "vi": "🇻🇳",
  "cy": "🏴󠁧󠁢󠁷󠁬󠁳󠁿",
  "xh": "🇿🇦",
  "yo": "🇳🇬",
  "zu": "🇿🇦",
  "zh-TW": "🇨🇳",
  "zh": "🇨🇳",
  "zh-CN": "🇨🇳",
  "ab": "",
  "ace": "🇮🇩",
  "ach": "🇺🇬",
  "aa": "🇪🇹",
  "alz": "🇺🇬",
  "av": "🇷🇺",
  "awa": "🇮🇳",
  "ban": "🇮🇩",
  "bal": "🇮🇷",
  "bci": "🇨🇮",
  "ba": "🇷🇺",
  "btx": "🇮🇩",
  "bts": "🇮🇩",
  "bbc": "🇮🇩",
  "bem": "🇿🇲",
  "bew": "🇮🇩",
  "bik": "🇵🇭",
  "br": "🇫🇷",
  "bua": "🇷🇺",
  "yue": "🇭🇰",
  "ch": "🇬🇺",
  "ce": "🇷🇺",
  "chk": "🇫🇲",
  "cv": "🇷🇺",
  "crh": "🇺🇦",
  "fa-AF": "🇦🇫",
  "din": "🇸🇸",
  "dov": "🇨🇩",
  "dyu": "🇲🇱",
  "dz": "🇧🇹",
  "fo": "🇫🇴",
  "fj": "🇫🇯",
  "fon": "🇧🇯",
  "fur": "🇮🇹",
  "ff": "🇲🇱",
  "gaa": "🇬🇭",
  "cnh": "🇲🇲",
  "hil": "🇵🇭",
  "hrx": "🇩🇪",
  "iba": "🇲🇾",
  "jam": "🇯🇲",
  "jw": "🇮🇩",
  "kac": "🇨🇳",
  "kl": "🇬🇱",
  "kr": "🇳🇪",
  "pam": "🇵🇭",
  "kha": "🇮🇳",
  "cgg": "🇺🇬",
  "kg": "🇨🇩",
  "ktu": "🇨🇩",
  "trp": "🇮🇳",
  "kv": "🇷🇺",
  "ltg": "🇱🇻",
  "lij": "🇮🇹",
  "li": "🇳🇱",
  "lmo": "🇮🇹",
  "luo": "🇰🇪",
  "mad": "🇮🇩",
  "mak": "🇮🇩",
  "ms-Arab": "🇲🇾",
  "mam": "🇬🇹",
  "gv": "🇮🇲",
  "mh": "🇲🇭",
  "mwr": "🇮🇳",
  "mfe": "🇲🇺",
  "chm": "🇷🇺",
  "mni-Mtei": "🇮🇳",
  "min": "🇮🇩",
  "lus": "🇮🇳",
  "nhe": "🇲🇽",
  "ndc-ZW": "🇿🇼",
  "nr": "🇿🇼",
  "new": "🇳🇵",
  "bm-Nkoo": "🇬🇳",
  "nus": "🇸🇸",
  "oc": "🇫🇷",
  "or": "🇮🇳",
  "om": "🇪🇹",
  "os": "🇷🇺",
  "pag": "🇵🇭",
  "pap": "🇦🇼",
  "pt-PT": "🇵🇹",
  "pa": "🇮🇳",
  "pa-Arab": "🇵🇰",
  "kek": "🇬🇹",
  "qu": "🇵🇪",
  "rom": "🇷🇴",
  "rn": "🇧🇮",
  "se": "🇳🇴",
  "sg": "🇨🇫",
  "sat-Latn": "🇮🇳",
  "crs": "🇸🇨",
  "shn": "🇲🇲",
  "scn": "🇮🇹",
  "szl": "🇵🇱",
  "sd": "🇵🇰",
  "sus": "🇬🇳",
  "ss": "🇸🇿",
  "ty": "🇵🇫",
  "ber-Latn": "🇩🇿",
  "ber": "🇩🇿",
  "ta": "🇮🇳",
  "tt": "🇷🇺",
  "tet": "🇹🇱",
  "bo": "🇨🇳",
  "tiv": "🇳🇬",
  "tpi": "🇵🇬",
  "to": "🇹🇴",
  "tn": "🇧🇼",
  "tcy": "🇮🇳",
  "tum": "🇲🇼",
  "tyv": "🇷🇺",
  "udm": "🇷🇺",
  "ug": "🇨🇳",
  "ve": "🇿🇦",
  "vec": "🇮🇹",
  "war": "🇵🇭",
  "wo": "🇸🇳",
  "sah": "🇷🇺",
  "yi": "",
  "yua": "🇲🇽",
  "zap": "🇲🇽"
})

module.exports.TRANSLATE_LANGUAGE_MAPPINGS = Object.freeze({
  "af": "🇿🇦",
  "sq": "🇦🇱",
  "am": "🇪🇹",
  "ar": "",
  "hy": "🇦🇲",
  "as": "",
  "ay": "",
  "az": "🇦🇿",
  "bm": "",
  "eu": "",
  "be": "🇧🇾",
  "bn": "🇧🇩",
  "bho": "",
  "bs": "🇧🇦",
  "bg": "🇧🇬",
  "ca": "",
  "ceb": "🇵🇭",
  "co": "",
  "hr": "🇭🇷",
  "cs": "🇨🇿",
  "da": "🇩🇰",
  "dv": "",
  "doi": "",
  "nl": "🇳🇱",
  "en": "🇺🇸",
  "eo": "",
  "et": "🇪🇪",
  "ee": "",
  "fil": "🇵🇭",
  "fi": "🇫🇮",
  "fr": "🇫🇷",
  "fy": "",
  "gl": "",
  "ka": "🇬🇪",
  "de": "🇩🇪",
  "el": "🇬🇷",
  "gn": "",
  "gu": "",
  "ht": "🇭🇹",
  "ha": "🇳🇬",
  "haw": "",
  "he": "🇮🇱",
  "iw": "🇮🇱",
  "hi": "🇮🇳",
  "hmn": "",
  "hu": "🇭🇺",
  "is": "🇮🇸",
  "ig": "🇳🇬",
  "ilo": "",
  "id": "🇮🇩",
  "ga": "🇮🇪",
  "it": "🇮🇹",
  "ja": "🇯🇵",
  "jv": "",
  "kn": "",
  "kk": "🇰🇿",
  "km": "🇰🇭",
  "rw": "",
  "gom": "",
  "ko": "🇰🇷",
  "kri": "",
  "ku": "",
  "ckb": "",
  "ky": "🇰🇬",
  "lo": "🇱🇦",
  "la": "",
  "lv": "🇱🇻",
  "ln": "",
  "lt": "🇱🇹",
  "lg": "",
  "lb": "🇱🇺",
  "mk": "🇲🇰",
  "mai": "",
  "mg": "🇲🇬",
  "ms": "🇲🇾",
  "ml": "",
  "mt": "🇲🇹",
  "mi": "🇳🇿",
  "mr": "🇮🇳",
  "mn": "🇲🇳",
  "my": "🇲🇲",
  "ne": "🇳🇵",
  "no": "🇳🇴",
  "ny": "🇲🇼",
  "ps": "🇦🇫",
  "fa": "🇮🇷",
  "pl": "🇵🇱",
  "pt": "🇵🇹",
  "pt-pt": "🇵🇹",
  "pt-PT": "🇵🇹",
  "pt-br": "🇧🇷",
  "ro": "🇷🇴",
  "ru": "🇷🇺",
  "sm": "🇼🇸",
  "sa": "",
  "gd": "🏴󠁧󠁢󠁳󠁣󠁴󠁿",
  "nso": "",
  "sr": "🇷🇸",
  "st": "🇱🇸",
  "sn": "🇿🇼",
  "si": "🇱🇰",
  "sk": "🇸🇰",
  "sl": "🇸🇮",
  "so": "🇸🇴",
  "es": "🇪🇸",
  "su": "🇸🇩",
  "sw": "🇰🇪",
  "sv": "🇸🇪",
  "tl": "🇵🇭",
  "tg": "🇹🇯",
  "te": "🇮🇳",
  "th": "🇹🇭",
  "ti": "🇪🇷",
  "ts": "🇹🇴",
  "tr": "🇹🇷",
  "tk": "🇹🇲",
  "ak": "🇬🇭",
  "uk": "🇺🇦",
  "ur": "🇵🇰",
  "uz": "🇺🇿",
  "vi": "🇻🇳",
  "cy": "🏴󠁧󠁢󠁷󠁬󠁳󠁿",
  "xh": "🇿🇦",
  "yo": "🇳🇬",
  "zu": "🇿🇦",
  "zh-TW": "🇨🇳",
  "zh": "🇨🇳",
  "zh-CN": "🇨🇳",
})

module.exports.TRANSLATE_LANGUAGES = Object.freeze({
  // 1p auto
  "auto": "Automatic",
  // Translate API will respond with "und" if the language is unknown
  "und": "Detected Language",
  "ab": "Abkhaz",
  "ace": "Acehnese",
  "ach": "Acholi",
  "aa": "Afar",
  "af": "Afrikaans",
  "sq": "Albanian",
  "alz": "Alur",
  "am": "Amharic",
  "ar": "Arabic",
  "hy": "Armenian",
  "as": "Assamese",
  "av": "Avar",
  "awa": "Awadhi",
  "ay": "Aymara",
  "az": "Azerbaijani",
  "ban": "Balinese",
  "bal": "Baluchi",
  "bm": "Bambara",
  "bci": "Baoulé",
  "ba": "Bashkir",
  "eu": "Basque",
  "btx": "Batak Karo",
  "bts": "Batak Simalungun",
  "bbc": "Batak Toba",
  "be": "Belarusian",
  "bem": "Bemba",
  "bn": "Bengali",
  "bew": "Betawi",
  "bho": "Bhojpuri",
  "bik": "Bikol",
  "bs": "Bosnian",
  "br": "Breton",
  "bg": "Bulgarian",
  "bua": "Buryat",
  "yue": "Cantonese",
  "ca": "Catalan",
  "ceb": "Cebuano",
  "ch": "Chamorro",
  "ce": "Chechen",
  "ny": "Chichewa",
  "zh": "Chinese (Simplified)",
  "zh-TW": "Chinese (Traditional)",
  "chk": "Chuukese",
  "cv": "Chuvash",
  "co": "Corsican",
  "crh": "Crimean Tatar",
  "hr": "Croatian",
  "cs": "Czech",
  "da": "Danish",
  "fa-AF": "Dari",
  "din": "Dinka",
  "dv": "Divehi",
  "doi": "Dogri",
  "dov": "Dombe",
  "nl": "Dutch",
  "dyu": "Dyula",
  "dz": "Dzongkha",
  "en": "English",
  "eo": "Esperanto",
  "et": "Estonian",
  "ee": "Ewe",
  "fo": "Faroese",
  "fj": "Fijian",
  "tl": "Filipino",
  "fi": "Finnish",
  "fon": "Fon",
  "fr": "French",
  "fy": "Frisian",
  "fur": "Friulian",
  "ff": "Fulfulde",
  "gaa": "Ga",
  "gl": "Galician",
  "lg": "Ganda",
  "ka": "Georgian",
  "de": "German",
  "el": "Greek",
  "gn": "Guarani",
  "gu": "Gujarati",
  "ht": "Haitian Creole",
  "cnh": "Hakha Chin",
  "ha": "Hausa",
  "haw": "Hawaiian",
  "iw": "Hebrew",
  "hil": "Hiligaynon",
  "hi": "Hindi",
  "hmn": "Hmong",
  "hu": "Hungarian",
  "hrx": "Hunsrik",
  "iba": "Iban",
  "is": "Icelandic",
  "ig": "Igbo",
  "ilo": "Iloko",
  "id": "Indonesian",
  "ga": "Irish Gaelic",
  "it": "Italian",
  "jam": "Jamaican Patois",
  "ja": "Japanese",
  "ja-Latn": "Japanese",
  "jw": "Javanese",
  "kac": "Jingpo",
  "kl": "Kalaallisut",
  "kn": "Kannada",
  "kr": "Kanuri",
  "pam": "Kapampangan",
  "kk": "Kazakh",
  "kha": "Khasi",
  "km": "Khmer",
  "cgg": "Kiga",
  "kg": "Kikongo",
  "rw": "Kinyarwanda",
  "ktu": "Kituba",
  "trp": "Kokborok",
  "kv": "Komi",
  "gom": "Konkani",
  "ko": "Korean",
  "kri": "Krio",
  "ku": "Kurdish (Kurmanji)",
  "ckb": "Kurdish (Sorani)",
  "ky": "Kyrgyz",
  "lo": "Lao",
  "ltg": "Latgalian",
  "la": "Latin",
  "lv": "Latvian",
  "lij": "Ligurian",
  "li": "Limburgan",
  "ln": "Lingala",
  "lt": "Lithuanian",
  "lmo": "Lombard",
  "luo": "Luo",
  "lb": "Luxembourgish",
  "mk": "Macedonian",
  "mad": "Madurese",
  "mai": "Maithili",
  "mak": "Makassar",
  "mg": "Malagasy",
  "ms": "Malay",
  "ms-Arab": "Malay (Jawi)",
  "ml": "Malayalam",
  "mt": "Maltese",
  "mam": "Mam",
  "gv": "Manx",
  "mi": "Maori",
  "mr": "Marathi",
  "mh": "Marshallese",
  "mwr": "Marwadi",
  "mfe": "Mauritian Creole",
  "chm": "Meadow Mari",
  "mni-Mtei": "Meiteilon (Manipuri)",
  "min": "Minang",
  "lus": "Mizo",
  "mn": "Mongolian",
  "my": "Myanmar (Burmese)",
  "nhe": "Nahuatl (Eastern Huasteca)",
  "ndc-ZW": "Ndau",
  "nr": "Ndebele (South)",
  "new": "Nepalbhasa (Newari)",
  "ne": "Nepali",
  "bm-Nkoo": "NKo",
  "nso": "Northern Sotho",
  "no": "Norwegian",
  "nus": "Nuer",
  "oc": "Occitan",
  "or": "Odia (Oriya)",
  "om": "Oromo",
  "os": "Ossetian",
  "pag": "Pangasinan",
  "pap": "Papiamento",
  "ps": "Pashto",
  "fa": "Persian",
  "pl": "Polish",
  "pt": "Portuguese",
  "pt-PT": "Portuguese (Portugal)",
  "pa": "Punjabi",
  "pa-Arab": "Punjabi (Shahmukhi)",
  "kek": "Q'eqchi'",
  "qu": "Quechua",
  "rom": "Romani",
  "ro": "Romanian",
  "rn": "Rundi",
  "ru": "Russian",
  "se": "Sami (North)",
  "sm": "Samoan",
  "sg": "Sango",
  "sa": "Sanskrit",
  "sat-Latn": "Santali",
  "gd": "Scots Gaelic",
  "sr": "Serbian",
  "st": "Sesotho",
  "crs": "Seychellois Creole",
  "shn": "Shan",
  "sn": "Shona",
  "scn": "Sicilian",
  "szl": "Silesian",
  "sd": "Sindhi",
  "si": "Sinhala",
  "sk": "Slovak",
  "sl": "Slovenian",
  "so": "Somali",
  "es": "Spanish",
  "su": "Sundanese",
  "sus": "Susu",
  "sw": "Swahili",
  "ss": "Swati",
  "sv": "Swedish",
  "ty": "Tahitian",
  "tg": "Tajik",
  "ber-Latn": "Tamazight",
  "ber": "Tamazight (Tifinagh)",
  "ta": "Tamil",
  "tt": "Tatar",
  "te": "Telugu",
  "tet": "Tetum",
  "th": "Thai",
  "bo": "Tibetan",
  "ti": "Tigrinya",
  "tiv": "Tiv",
  "tpi": "Tok Pisin",
  "to": "Tongan",
  "ts": "Tsonga",
  "tn": "Tswana",
  "tcy": "Tulu",
  "tum": "Tumbuka",
  "tr": "Turkish",
  "tk": "Turkmen",
  "tyv": "Tuvan",
  "ak": "Twi",
  "udm": "Udmurt",
  "uk": "Ukrainian",
  "ur": "Urdu",
  "ug": "Uyghur",
  "uz": "Uzbek",
  "ve": "Venda",
  "vec": "Venetian",
  "vi": "Vietnamese",
  "war": "Waray",
  "cy": "Welsh",
  "wo": "Wolof",
  "xh": "Xhosa",
  "sah": "Yakut",
  "yi": "Yiddish",
  "yo": "Yoruba",
  "yua": "Yucatec Maya",
  "zap": "Zapotec",
  "zu": "Zulu",
  "he": "Hebrew",
  "jv": "Javanese",
  "zh-CN": "Chinese (Simplified)"
})

module.exports.EMOJIPEDIA_PLATFORM_TYPES = [
  "apple",
  "google",
  "samsung",
  "joypixels",
  "microsoft",
  "facebook",
  "twitter",
  "whatsapp",
  "lg",
  "mozilla",
  "htc",
  "emojidex",
  "messenger",
  "softbank",
  "au-kddi",
  "docomo",
  "openmoji",
  "skype",
  "sony",
  "noto-emoji",
  "toss-face",
  "microsoft-teams",
  "animated-noto-color-emoji",
  "twitter-emoji-stickers",
  "emojipedia"
]

module.exports.EMOJIPEDIA_PLATFORM_TYPE_ALIASES = {
  "fluent": "microsoft-3D-fluent",
  "twemoji": "twitter",
  "playstation": "sony",
  "ios": "apple",
  "android": "google",
  "windows": "microsoft"
}

module.exports.GOOGLE_CLOUD_SAFETY_LABELS_NAMES = Object.freeze({
  "adult":    "Explicit Content ",
  "spoof":    "Modified Image   ",
  "medical":  "Medical Image    ",
  "violence": "Contains Violence",
  "racy":     "Lewd Content     "
})

module.exports.GOOGLE_CLOUD_SAFETY_LABELS = Object.freeze({
  "UNKNOWN": {
    icon: "question_large",
    name: "Unknown      "
  },
  "VERY_UNLIKELY": {
    icon: "exclaim_0",
    name: "Very Unlikely"
  },
  "UNLIKELY": {
    icon: "exclaim_1",
    name: "Unlikely     "
  },
  "POSSIBLE": {
    icon: "exclaim_2",
    name: "Possible     "
  },
  "LIKELY": {
    icon: "exclaim_3",
    name: "Likely       "
  },
  "VERY_LIKELY": {
    icon: "exclaim_4",
    name: "Very Likely  "
  }
})

module.exports.MAPKIT_ACTIONS = Object.freeze({
  SEARCH: "search",
  STATIC_MAP: "render"
})

module.exports.REXTESTER_LANGUAGES = Object.freeze({
  "bash": "38",
  "node": "23",
  "js": "23",
  "py2": "5",
  "py": "24",
  "java": "4",
  "lua": "14",
  "ruby": "12",
  "perl": "13",
  "go": "20",
  "kt": "43",
  "rust": "46",
  "php": "8",
  "c": "6",
  "cpp": "7",
  'cs': "1",
  "elixir": "41",
  "swift": "37",
  "bf": "44",
  "scala": "21",
  "haskell": "11"
})

module.exports.REXTESTER_COMPILER_ARGS = Object.freeze({
  "6": "-Wall -std=gnu99 -O2 -o a.out source_file.c",
  "7": "-Wall -std=c++14 -O2 -o a.out source_file.cpp",
  "11": "-o a.out source_file.hs"
})

module.exports.YOUTUBE_CATEGORIES = {
  "music": "10",
  "animals": "15",
  "sports": "17",
  "travel": "19",
  "gaming": "20",
  "comedy": "34",
  "news": "25",
  "howto": "26",
  "education": "27",
  "science": "28",
  "movies": "30",
  "animation": "31",
  "documentary": "35",
  "horror": "39",
  "fantasy": "40",
  "shorts": "42",
  "shows": "43"
}

// Special character that allows for fully hidden masked links on all (supported) platforms.
module.exports.HIDDEN_MASKED_LINK_CHARACTER = "󠄴";

// Allows force-displaying an incognito reason
module.exports.INCOGNITO_REASONS = Object.freeze({
  permissions: 50013
})

/**
 * These will force the command to become "incognito".
 */
module.exports.MESSAGE_BLOCK_REASONS = Object.freeze({
  20016: {
    message: "the channel's slowmode settings",
    support_article: 360016150952
  },
  200000: {
    message: "the server's AutoMod setup",
    support_article: 4421269296535
  },
  50013: {
    message: "the channel's permission setup",
    support_article: 10543994968087
  }
});

// Used by provisional accounts for the new partner SDK
module.exports.PROVISIONAL_ACCOUNT_AVATARS = Object.freeze([
  "https://discord.com/assets/cc4d3c817f9a1b57a4f2.png",
  "https://discord.com/assets/bea3e879099c0aacba64.png",
  "https://discord.com/assets/d569b695280979e11ca3.png",
  "https://discord.com/assets/0afec6e15d7c376edb17.png",
  "https://discord.com/assets/06c71afa509013e91173.png",
  "https://discord.com/assets/15a9b7ce7525b2fbe72f.png"
])

// Omnisearch

// Anime Format Types (/omni_service/endpoints/anime.js)
module.exports.OMNI_ANIME_FORMAT_TYPES = Object.freeze({
  ANIME: "Anime",
  TV: "TV",
  TV_SHORT: "TV Short",
  MOVIE: "Movie",
  SPECIAL: "Special",
  OVA: "OVA",
  ONA: "ONA",
  MUSIC: "Music",
  MANGA: "Manga",
  NOVEL: "Novel",
  ONE_SHOT: "One Shot"
})

module.exports.OMNI_MOVIE_TYPES = Object.freeze({
  "movie": "Movie",
  "tv": "TV Show"
})

// Assets

module.exports.SCREENSHOT_ASSET_REVISION = 250117;